@@ -3,7 +3,7 @@
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.10   update date: 2024-06-28
+# Version : 1.4.11   update date: 2024-12-11
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -142,6 +142,7 @@ LLOGSIZE=4096000
 SBSPACESIZE=4096000
 TEMPSIZE=4096000
 DATASIZE=10240000
+DMAXSIZE=204800000
 
 if [[ x"$DBS1GB" = xy || x"$DBS1GB" = xY ]]; then
   ROOTSIZE=1024000
@@ -258,6 +259,7 @@ chmod 0755 $INSTALL_DIR 2>/dev/null
 # ids_install
 mkdir -p ${WORKDIR}/tmp 2>/dev/null
 export IATEMPDIR=${WORKDIR}/tmp
+export LD_LIBRARY_PATH=/usr/lib64:/usr/lib:/lib64:/lib:/lib/x86_64-linux-gnu:/lib/aarch64-linux-gnu:$LD_LIBRARY_PATH
 _loginfo "Execute software install, this will take a moment."
 timeout 1800 ${WORKDIR}/install/ids_install -i silent -DLICENSE_ACCEPTED=TRUE -DUSER_INSTALL_DIR=${INSTALL_DIR:-/opt/${USER_NAME}}
 if [ ! $? -eq 0 ]; then
@@ -270,6 +272,10 @@ if [ ! $? -eq 0 ]; then
   exit 6
 fi
 
+if [ -f ${INSTALL_DIR}/etc/alarmprogram.sh ]; then
+  sed -i "s#ksh#sh#g" ${INSTALL_DIR}/etc/alarmprogram.sh
+fi
+
 ###### Init database
 [ ! -d /etc/${USER_NAME} ] && mkdir -p /etc/${USER_NAME} 2>/dev/null
 echo "USERS:daemon" > /etc/${USER_NAME}/allowed.surrogates
@@ -418,7 +424,8 @@ ADMIN_SQLFILE=${INSTALL_DIR}/temp/admin_sqlfile.sql
 mkdir -p ${INSTALL_DIR}/temp
 cat << ! > $ADMIN_SQLFILE 2>&1
 -- set datadbs01 extendable
-EXECUTE FUNCTION task ("modify chunk extendable on", 6);
+EXECUTE FUNCTION task ('modify chunk extendable on', 6);
+EXECUTE FUNCTION task ('modify space sp_sizes','datadbs01','10','100000','${DMAXSIZE}');
 -- set all task not run except idle_user_timeout
 update ph_task set tk_enable = 'f';
 update ph_task set tk_frequency = interval(00:30:00) hour to second, tk_enable = 't' 
@@ -546,6 +553,7 @@ sed -i "s#^OPT_GOAL.*#OPT_GOAL 0#g" $CFGFILE
 sed -i "s#^TAPEBLK.*#TAPEBLK 512#g" $CFGFILE
 sed -i "s#^LTAPEBLK.*#LTAPEBLK 512#g" $CFGFILE
 sed -i "s#^ALARMPROGRAM.*#ALARMPROGRAM \$GBASEDBTDIR/etc/log_full.sh#g" $CFGFILE
+# sed -i "s#^MAX_FILL_DATA_PAGES.*#MAX_FILL_DATA_PAGES 1#g" $CFGFILE
 
 if [ $NUMMEM -le 4096 ]; then
   sed -i "s#^DS_TOTAL_MEMORY.*#DS_TOTAL_MEMORY 128000#g" $CFGFILE
@@ -618,7 +626,7 @@ if [[ x"${SECNEED}" = xy || x"${SECNEED}" = xY ]]; then
   echo "+ gbasedbt" > ${INSTALL_DIR}/etc/host.trust
   chown ${USER_NAME}:${USER_NAME} ${INSTALL_DIR}/etc/host.trust 2>/dev/null
   chmod 0644 ${INSTALL_DIR}/etc/host.trust 2>/dev/null
- fi
+fi
 
 ####### restart database
 _loginfo "Restart GBase 8s Database Server."
@@ -626,9 +634,10 @@ su - ${USER_NAME} -c "timeout 1800 onmode -ky"
 sleep 5
 su - ${USER_NAME} -c "oninit -vy"
 if [ $? -eq 0 ]; then
-  _loginfo "Set audit mask."
-  su - dbsso -c "onaudit -a -u _default -e +DRDB,DRTB,ALTB,TCTB,STSN" 2>/dev/null
-
+  if [ x"$SECNEED" = xy -o x"$SECNEED" = xY ]; then
+    _loginfo "Set audit mask."
+    su - dbsso -c "onaudit -a -u _default -e +DRDB,DRTB,ALTB,TCTB,STSN" 2>/dev/null
+  fi
   _loginfo "Finish."
 else
   _loginfo "Restart Server with ERROR. Please reduce the memory parameters(SHMVIRTSIZE,BUFFPOOLS), and then restart the server."
