@@ -3,7 +3,7 @@
 # Filename: CheckEnv.sh
 # Function: Check Environment for GBase 8s install.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.10   update date: 2024-06-28
+# Version : 1.4.11   update date: 2024-12-11
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -20,7 +20,7 @@ if [ ${PINGOK} -eq 0 -a -x /usr/bin/yum ]; then
   yum -y install unzip tar java-1.8.0-openjdk glibc-devel ncurses-libs ncurses-compat-libs libnsl libaio
 elif [ ${PINGOK} -eq 0 -a -x /usr/bin/apt ]; then
   _loginfo "Try to execute apt install.."
-  apt -y install unzip tar openjdk-8-jdk glibc-tools libncurses5 libnsl-dev libaio-dev
+  apt -y install unzip tar openjdk-8-jdk glibc-tools libncurses-dev libncurses5-dev libnsl-dev libaio-dev
 fi
 
 ##### Tool Check
@@ -70,7 +70,14 @@ do
       FIND=$(cd $QP && find . -name $LIB)
     fi
     if [ ! x"${FIND}" = x ];then
-      break;
+      break
+    elif [ x"${FIND}" = x -a x"${LIB}" = xlibncurses.so.5 ]; then
+      L5FIND=$(cd $QP && find . -name "libncurses.so.6")
+      if [ ! x"${L5FIND}" = x ]; then
+        L5PREFIX=${QP}/${L5FIND:0:-15}
+        cd ${L5PREFIX} && ln -s libncurses.so.6 libncurses.so.5 && ln -s libtinfo.so.6 libtinfo.so.5
+        FIND="1"
+      fi
     fi
   done 
   if [ x"${FIND}" = x ];then
